package com.ydl.ydlcommon.data.http;

import androidx.annotation.Keep;

/**
 * Post请求表单
 */
@Keep
public class FormatText {
    //key
    private String mKey;
    //value
    private String mValue;

    public FormatText(String mKey, String mValue) {
        this.mKey = mKey;
        this.mValue = mValue;
    }

    public String getmKey() {
        return mKey;
    }

    public String getmValue() {
        return mValue;
    }

    @Override
    public String toString() {
        return "FormatText{" +
                "mKey='" + mKey + '\'' +
                ", mValue='" + mValue + '\'' +
                '}';
    }
}
